import React from 'react';
import SvgIcon from '../../../components/SvgIcon';

export default function RequestDetailSlideOver({
    show,
    onClose,
    request,
    onApprove,
    onReject,
    processingId,
    approveRejectStatus,
    isApproving,
}) {
    if (!request) return null;

    // 从通知数据中获取申请人信息
    const applicant = request.applicant || request.title || '未知用户';
    const applicantInitial = applicant.charAt(0);

    return (
        <>
            <div className={`slide-over-backdrop ${show ? 'show' : ''}`} onClick={onClose}></div>
            <div className={`slide-over ${show ? 'show' : ''}`}>
                <div className='slide-over-content'>
                    <div className='slide-over-header'>
                        <h5 className='mb-0'>申请详情</h5>
                        <button type='button' className='btn-close' onClick={onClose}></button>
                    </div>
                    <div className='slide-over-body'>
                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>申请人信息</h6>
                            <div className='d-flex align-items-center mb-3'>
                                <div className='avatar-placeholder me-3 bg-dark'>{applicantInitial}</div>
                                <div>
                                    <h5 className='mb-1'>{applicant}</h5>
                                </div>
                            </div>
                        </div>

                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>知识库信息</h6>
                            <p className='mb-1'>
                                <strong>ID：</strong> {request.knowledge_base || request.content || '未知知识库'}
                            </p>
                        </div>

                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>申请权限</h6>
                            <div className='d-flex flex-wrap gap-2 mb-3'>
                                {request.permissions?.can_read && !request.permissions?.can_edit && (
                                    <span className='badge bg-warning-subtle text-warning d-flex align-items-center gap-1'>
                                        只读
                                    </span>
                                )}
                                {request.permissions?.can_edit && request.permissions?.can_delete && (
                                    <span className='badge bg-success-subtle text-success d-flex align-items-center gap-1'>
                                        完全访问
                                    </span>
                                )}
                            </div>
                        </div>

                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>申请时间</h6>
                            <p className='mb-1'>{new Date(request.created_at || Date.now()).toLocaleString()}</p>
                        </div>

                        {request.expires_at && (
                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>到期时间</h6>
                                <p className='mb-1'>{new Date(request.expires_at).toLocaleString()}</p>
                            </div>
                        )}

                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>申请理由</h6>
                            <div className='p-3 bg-light rounded'>
                                {request.reason || request.content || '无申请理由'}
                            </div>
                        </div>
                    </div>
                    <div className='slide-over-footer'>
                        <button
                            className='btn btn-outline-danger me-2'
                            onClick={() => onReject(request.id)}
                            disabled={processingId === request.id && approveRejectStatus === 'loading'}
                        >
                            {processingId === request.id && approveRejectStatus === 'loading' && !isApproving ? (
                                <>
                                    <span
                                        className='spinner-border spinner-border-sm me-1'
                                        role='status'
                                        aria-hidden='true'
                                    ></span>
                                    处理中...
                                </>
                            ) : (
                                <>拒绝</>
                            )}
                        </button>
                        <button
                            className='btn btn-outline-success'
                            onClick={() => onApprove(request.id)}
                            disabled={processingId === request.id && approveRejectStatus === 'loading'}
                        >
                            {processingId === request.id && approveRejectStatus === 'loading' && isApproving ? (
                                <>
                                    <span
                                        className='spinner-border spinner-border-sm me-1'
                                        role='status'
                                        aria-hidden='true'
                                    ></span>
                                    处理中...
                                </>
                            ) : (
                                <>批准</>
                            )}
                        </button>
                    </div>
                </div>
            </div>
        </>
    );
}
